@@ -247,7 +247,7 @@ void Preferences::addIgnore(const QString &newIgnore)
 
 bool Preferences::removeIgnore(const QString &oldIgnore)
 {
-    for (Ignore *ignore : qAsConst(self()->mIgnoreList)) {
+    for (Ignore *ignore : std::as_const(self()->mIgnoreList)) {
         if (ignore->getName().toLower() == oldIgnore.toLower())
         {
             self()->mIgnoreList.removeOne(ignore);
@@ -261,7 +261,7 @@ bool Preferences::removeIgnore(const QString &oldIgnore)
 
 bool Preferences::isIgnored(const QString &nickname)
 {
-    for (Ignore *ignore : qAsConst(self()->mIgnoreList)) {
+    for (Ignore *ignore : std::as_const(self()->mIgnoreList)) {
         if (ignore->getName().section(QLatin1Char('!'),0,0).toLower()==nickname.toLower())
         {
             return true;
@@ -398,7 +398,7 @@ QStringList Preferences::defaultAliasList()
 
     QStringList aliasList;
 
-    for (const QString& script : qAsConst(scripts)) {
+    for (const QString& script : std::as_const(scripts)) {
         aliasList.append(QStringLiteral("%1 /exec %1").arg(script));
 
         // FIXME: Historically, defaultAliasList() is primarily used to dynamically
